@@ -10,6 +10,11 @@ import cherrypy
 import logging
 from . import errors
 
+try:
+    basestring
+except:
+    basestring = str
+
 
 BaseMdl = declarative_base ()
 
@@ -62,7 +67,7 @@ class Manager (object):
         orm.catalog.put (self.pool_name, session)
 
     def _update_keys (self):
-        self.keys = {key: dict (data) for key, data in self.gpg.list_keys ().keys.iteritems ()}
+        self.keys = {key: dict (data) for key, data in self.gpg.list_keys ().keys.items ()}
 
     def _prepare_keys (self, keys):
         if isinstance (keys, basestring):
