@@ -6,6 +6,10 @@ import sys
 from . import _xmlrpclib, errors
 
 
+if sys.version_info [0] >= 3:
+    unicode = str
+
+
 class EncryptedXmlrpcTool (cherrypy.Tool):
     '''
     Инструмент для замены tools.xmlrpc в криптоинтерфейсах.
@@ -67,6 +71,9 @@ class EncryptedXmlrpcTool (cherrypy.Tool):
             body = request.rco_security.encrypt (body, request.rco_client).encode ('utf-8')
         else:
             ct = 'text/xml'
+            
+        if sys.version_info [0] >= 3 and isinstance(body, str):
+            body = body.encode('utf-8')
 
         response.headers ['Content-Type'] = ct
         response.headers ['Content-Length'] = len (body)
